@@ -1,9 +1,9 @@
-#line 7529 "../../doc/bison.texinfo"
+#line 7679 "../../doc/bison.texinfo"
 #include <iostream>
 #include "calc++-driver.hh"
 
 int
-main (int argc, const char* argv[])
+main (int argc, char *argv[])
 {
   calcxx_driver driver;
   for (++argv; argv[0]; ++argv)
